@@ -1,8 +1,6 @@
 from __future__ import annotations
 
-from typing import Dict, List, Optional, Union
-
-from typing_extensions import Literal
+from typing import Dict, List, Literal, Optional, Union
 
 from samtranslator.internal.schema_source.aws_serverless_connector import EmbeddedConnector
 from samtranslator.internal.schema_source.common import (
@@ -79,7 +77,6 @@ class LambdaRequestAuthorizerIdentity(BaseModel):
 
 
 class LambdaTokenAuthorizer(BaseModel):
-    AuthorizationScopes: Optional[List[str]] = lambdatokenauthorizer("AuthorizationScopes")
     FunctionArn: SamIntrinsicable[str] = lambdatokenauthorizer("FunctionArn")
     FunctionInvokeRole: Optional[str] = lambdatokenauthorizer("FunctionInvokeRole")
     FunctionPayloadType: Optional[Literal["TOKEN"]] = lambdatokenauthorizer("FunctionPayloadType")
@@ -88,7 +85,6 @@ class LambdaTokenAuthorizer(BaseModel):
 
 
 class LambdaRequestAuthorizer(BaseModel):
-    AuthorizationScopes: Optional[List[str]] = lambdarequestauthorizer("AuthorizationScopes")
     FunctionArn: SamIntrinsicable[str] = lambdarequestauthorizer("FunctionArn")
     FunctionInvokeRole: Optional[str] = lambdarequestauthorizer("FunctionInvokeRole")
     FunctionPayloadType: Optional[Literal["REQUEST"]] = lambdarequestauthorizer("FunctionPayloadType")
@@ -158,18 +154,27 @@ class Route53(BaseModel):
     SetIdentifier: Optional[PassThroughProp]  # TODO: add docs
     Region: Optional[PassThroughProp]  # TODO: add docs
     SeparateRecordSetGroup: Optional[bool]  # TODO: add docs
+    VpcEndpointDomainName: Optional[PassThroughProp]  # TODO: add docs
+    VpcEndpointHostedZoneId: Optional[PassThroughProp]  # TODO: add docs
+
+
+class AccessAssociation(BaseModel):
+    VpcEndpointId: PassThroughProp  # TODO: add docs
 
 
 class Domain(BaseModel):
     BasePath: Optional[PassThroughProp] = domain("BasePath")
     NormalizeBasePath: Optional[bool] = domain("NormalizeBasePath")
+    Policy: Optional[PassThroughProp]
     CertificateArn: PassThroughProp = domain("CertificateArn")
     DomainName: PassThroughProp = passthrough_prop(
         DOMAIN_STEM,
         "DomainName",
         ["AWS::ApiGateway::DomainName", "Properties", "DomainName"],
     )
-    EndpointConfiguration: Optional[SamIntrinsicable[Literal["REGIONAL", "EDGE"]]] = domain("EndpointConfiguration")
+    EndpointConfiguration: Optional[SamIntrinsicable[Literal["REGIONAL", "EDGE", "PRIVATE"]]] = domain(
+        "EndpointConfiguration"
+    )
     MutualTlsAuthentication: Optional[PassThroughProp] = passthrough_prop(
         DOMAIN_STEM,
         "MutualTlsAuthentication",
@@ -186,6 +191,7 @@ class Domain(BaseModel):
         "SecurityPolicy",
         ["AWS::ApiGateway::DomainName", "Properties", "SecurityPolicy"],
     )
+    AccessAssociation: Optional[AccessAssociation]
 
 
 class DefinitionUri(BaseModel):
@@ -308,6 +314,7 @@ class Properties(BaseModel):
     OpenApiVersion: Optional[OpenApiVersion] = properties("OpenApiVersion")
     StageName: SamIntrinsicable[str] = properties("StageName")
     Tags: Optional[DictStrAny] = properties("Tags")
+    Policy: Optional[PassThroughProp]  # TODO: add docs
     PropagateTags: Optional[bool]  # TODO: add docs
     TracingEnabled: Optional[TracingEnabled] = passthrough_prop(
         PROPERTIES_STEM,
